This is a code linting function and expected to be called at the console
during package development. It will scan the files in the current project and
replace unqualified references to e.g. mutate with ones to dplyr::mutate
etc. All changes are made after a commit which can be reverted.
Value
a tibble with columns path, pkg, name, and value summarising
which unqualified function calls were found in which files, or NULL if
no fixes were needed.
Examples
if (FALSE) {
# Fix all unqualified function calls in a package:
fix_unqualified_fns_bulk()
# Restrict to specific directories:
fix_unqualified_fns_bulk(rDirectories = here::here("R"))
}