Creates symlinks from system.file("pkgtools", "*.R") into
~/.local/bin/, allowing each exported function to be run as a command-line
script.
Creates symlinks from system.file("pkgtools", "*.R") into
~/.local/bin/, allowing each exported function to be run as a command-line
script.