This function makes multiple changes to the package. It adds packaged data
files from the data directory to a pkgdown github published pin board and
constructs a minimal set of functions with the same names as the data to
access the data from the pinboard. It finds any references to the dataset in
the code directories (data-raw,R,vignettes,test) and replaces them
with a function call of the same name.
Examples
if (FALSE) {
# Migrate all package data to a pins board:
migrate_to_pins()
# Migrate specific datasets:
migrate_to_pins(migrate = c("mtcars", "iris"))
}