Skip to contents

This function amends DESCRIPTION to register pkgtools as a build-time dependency and adds pkgtools to the Roxygen packages field. Call it once when setting up a new package that will use @unit and @dparam custom roxygen tags.

Usage

use_unit_test(path = ".")

Arguments

path

character path to the package

Value

Nothing: called for file system side effects.

Examples

if (FALSE) {
  use_unit_test("/path/to/my/package")
}