Reverts to last state committed by pkgtools, and stashes any unstaged changes.
All pkgtools functions that modify files commit before making changes and
record the commit hash. This function rolls back to that commit.
Reverts to last state committed by pkgtools, and stashes any unstaged changes.
All pkgtools functions that modify files commit before making changes and
record the commit hash. This function rolls back to that commit.