Expands a whisker-based template file by substituting named placeholders.
Templates are stored in inst/templates/ and selected from via a menu
if .template_name is not specified. The resulting file is written to
R/generated-*.R.
Arguments
- .template_name
if not given a dialog will be presented with the options
- ...
supplied as parameters to the template. template placeholders such as
`xxx.#name#_yyy`, will be substituted withxxx.myname_yyyifname="myname". The first value of this list will be used for`##`placeholders- .overwrite
overwrte the destination file if it exists
- .destfile
if given will write the expanded template here.