This function amends DESCRIPTION to register pkgtools as a build-time
dependency and adds pkgtools to the Roxygen packages field. Call it
once when setting up a new package that will use @unit and @dparam
custom roxygen tags.
This function amends DESCRIPTION to register pkgtools as a build-time
dependency and adds pkgtools to the Roxygen packages field. Call it
once when setting up a new package that will use @unit and @dparam
custom roxygen tags.